@@ -69,13 +69,14 @@ def generate_file(graph, target_column, task_type, colab=False):
                 f.write(
                     "\t"
                     + essentials_handler.return_function(
-                        function_name=node["data"]["name"], params=params
+                        function_name=node["data"]["name"], params=params, task_type=task_type, target_column= target_column
                     )
                 )
                 f.write("\n")
             elif steps_list[i] == "evaluate_model":
                 f.write(
-                    f"\tmetrics = huble.sklearn.evaluate_model(model=Model, test_dataset=test_dataset, target_column= '{target_column}', task_type='{task_type}' )"
+                    # TODO: make changes for clustering
+                    f"\tmetrics = huble.sklearn.evaluate_model(model=Model, training_dataset=training_dataset, test_dataset=test_dataset, target_column= '{target_column}', task_type='{task_type}' )"
                 )
                 f.write("\n")
             elif steps_list[i] == "primary_dataset":
